@@ -130,7 +130,7 @@
 
 
 /* Copy the first part of user declarations.  */
-#line 1 "./langdefparser.yy"
+#line 1 "../../../lib/srchilite/langdefparser.yy"
 
 /*
  * Copyright (C) 1999-2009 Lorenzo Bettini <http://www.lorenzobettini.it>
@@ -241,7 +241,7 @@ struct ElementNamesList : ElementNames {
 
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
 typedef union YYSTYPE
-#line 91 "./langdefparser.yy"
+#line 91 "../../../lib/srchilite/langdefparser.yy"
 {
   int tok ; /* command */
   bool booloption ;
@@ -1246,7 +1246,7 @@ yydestruct (yymsg, yytype, yyvaluep, yylocationp)
   switch (yytype)
     {
       case 34: /* "elemdefs" */
-#line 126 "./langdefparser.yy"
+#line 126 "../../../lib/srchilite/langdefparser.yy"
 	{
 	//std::cout << "freeing discarded symbol" << std::endl;
 	delete (yyvaluep->langelems);
@@ -1254,7 +1254,7 @@ yydestruct (yymsg, yytype, yyvaluep, yylocationp)
 #line 1255 "langdefparser.cc"
 	break;
       case 35: /* "elemdef" */
-#line 126 "./langdefparser.yy"
+#line 126 "../../../lib/srchilite/langdefparser.yy"
 	{
 	//std::cout << "freeing discarded symbol" << std::endl;
 	delete (yyvaluep->langelem);
@@ -1262,7 +1262,7 @@ yydestruct (yymsg, yytype, yyvaluep, yylocationp)
 #line 1263 "langdefparser.cc"
 	break;
       case 37: /* "key" */
-#line 126 "./langdefparser.yy"
+#line 126 "../../../lib/srchilite/langdefparser.yy"
 	{
 	//std::cout << "freeing discarded symbol" << std::endl;
 	delete (yyvaluep->key);
@@ -1270,7 +1270,7 @@ yydestruct (yymsg, yytype, yyvaluep, yylocationp)
 #line 1271 "langdefparser.cc"
 	break;
       case 38: /* "keys" */
-#line 126 "./langdefparser.yy"
+#line 126 "../../../lib/srchilite/langdefparser.yy"
 	{
 	//std::cout << "freeing discarded symbol" << std::endl;
 	delete (yyvaluep->keys);
@@ -1278,7 +1278,7 @@ yydestruct (yymsg, yytype, yyvaluep, yylocationp)
 #line 1279 "langdefparser.cc"
 	break;
       case 47: /* "stringdefs" */
-#line 126 "./langdefparser.yy"
+#line 126 "../../../lib/srchilite/langdefparser.yy"
 	{
 	//std::cout << "freeing discarded symbol" << std::endl;
 	delete (yyvaluep->stringdefs);
@@ -1286,7 +1286,7 @@ yydestruct (yymsg, yytype, yyvaluep, yylocationp)
 #line 1287 "langdefparser.cc"
 	break;
       case 49: /* "stringdef" */
-#line 126 "./langdefparser.yy"
+#line 126 "../../../lib/srchilite/langdefparser.yy"
 	{
 	//std::cout << "freeing discarded symbol" << std::endl;
 	delete (yyvaluep->stringdef);
@@ -1614,7 +1614,7 @@ yyreduce:
   switch (yyn)
     {
         case 2:
-#line 134 "./langdefparser.yy"
+#line 134 "../../../lib/srchilite/langdefparser.yy"
     {
           /* no definitions (i.e., empty a .lang file with no definition) */
           /* such as, default.lang */
@@ -1627,12 +1627,12 @@ yyreduce:
     break;
 
   case 3:
-#line 143 "./langdefparser.yy"
+#line 143 "../../../lib/srchilite/langdefparser.yy"
     { current_lang_elems = (yyvsp[(1) - (1)].langelems); }
     break;
 
   case 4:
-#line 146 "./langdefparser.yy"
+#line 146 "../../../lib/srchilite/langdefparser.yy"
     {
               (yyval.langelems) = (yyvsp[(1) - (2)].langelems);
               ADD_ELEMENT((yyval.langelems), (yyvsp[(2) - (2)].langelem));
@@ -1640,7 +1640,7 @@ yyreduce:
     break;
 
   case 5:
-#line 150 "./langdefparser.yy"
+#line 150 "../../../lib/srchilite/langdefparser.yy"
     {
               (yyval.langelems) = new LangElems;
               ADD_ELEMENT((yyval.langelems), (yyvsp[(1) - (1)].langelem));
@@ -1648,7 +1648,7 @@ yyreduce:
     break;
 
   case 6:
-#line 157 "./langdefparser.yy"
+#line 157 "../../../lib/srchilite/langdefparser.yy"
     {
             (yyval.langelem) = (yyvsp[(2) - (3)].statestartlangelem);
             if ((yyvsp[(3) - (3)].tok) < 0)
@@ -1660,7 +1660,7 @@ yyreduce:
     break;
 
   case 7:
-#line 166 "./langdefparser.yy"
+#line 166 "../../../lib/srchilite/langdefparser.yy"
     {
             StateLangElem *statelangelem = new StateLangElem((yyvsp[(3) - (6)].statestartlangelem)->getName(), (yyvsp[(3) - (6)].statestartlangelem), (yyvsp[(5) - (6)].langelems), !(yyvsp[(2) - (6)].booloption));
             (yyval.langelem) = statelangelem;
@@ -1671,7 +1671,7 @@ yyreduce:
     break;
 
   case 8:
-#line 173 "./langdefparser.yy"
+#line 173 "../../../lib/srchilite/langdefparser.yy"
     {
             vardefinitions->add(*(yyvsp[(2) - (4)].string), (yyvsp[(4) - (4)].stringdefs));
             (yyval.langelem) = 0;
@@ -1679,7 +1679,7 @@ yyreduce:
     break;
 
   case 9:
-#line 177 "./langdefparser.yy"
+#line 177 "../../../lib/srchilite/langdefparser.yy"
     {
             // this token is used by the scanner to signal an error
             // in opening an include file
@@ -1692,7 +1692,7 @@ yyreduce:
     break;
 
   case 10:
-#line 189 "./langdefparser.yy"
+#line 189 "../../../lib/srchilite/langdefparser.yy"
     {
                   (yyval.statestartlangelem) = new DelimitedLangElem(*((yyvsp[(1) - (7)].key)->key), (yyvsp[(3) - (7)].stringdef), (yyvsp[(4) - (7)].stringdef), (yyvsp[(5) - (7)].stringdef), (yyvsp[(6) - (7)].booloption), (yyvsp[(7) - (7)].booloption));
                   (yyval.statestartlangelem)->setParserInfo((yyvsp[(1) - (7)].key));
@@ -1702,7 +1702,7 @@ yyreduce:
     break;
 
   case 11:
-#line 195 "./langdefparser.yy"
+#line 195 "../../../lib/srchilite/langdefparser.yy"
     {
               (yyval.statestartlangelem) = new DelimitedLangElem(*((yyvsp[(1) - (3)].key)->key), (yyvsp[(3) - (3)].stringdef), 0, 0, false, false);
               (yyval.statestartlangelem)->setParserInfo((yyvsp[(1) - (3)].key));
@@ -1711,7 +1711,7 @@ yyreduce:
     break;
 
   case 12:
-#line 200 "./langdefparser.yy"
+#line 200 "../../../lib/srchilite/langdefparser.yy"
     {
               (yyval.statestartlangelem) = new StringListLangElem(*((yyvsp[(1) - (4)].key)->key), (yyvsp[(3) - (4)].stringdefs), (yyvsp[(4) - (4)].booloption));
               (yyval.statestartlangelem)->setParserInfo((yyvsp[(1) - (4)].key));
@@ -1721,7 +1721,7 @@ yyreduce:
     break;
 
   case 13:
-#line 206 "./langdefparser.yy"
+#line 206 "../../../lib/srchilite/langdefparser.yy"
     {
           		(yyval.statestartlangelem) = new NamedSubExpsLangElem((yyvsp[(2) - (5)].keys), new StringDef(*(yyvsp[(5) - (5)].string)));
                         (yyval.statestartlangelem)->setParserInfo(parsestruct->file_name, (yylsp[(1) - (5)]).first_line);
@@ -1729,7 +1729,7 @@ yyreduce:
     break;
 
   case 14:
-#line 212 "./langdefparser.yy"
+#line 212 "../../../lib/srchilite/langdefparser.yy"
     {
     (yyval.key) = new Key;
     (yyval.key)->key = (yyvsp[(1) - (1)].string);
@@ -1738,7 +1738,7 @@ yyreduce:
     break;
 
   case 15:
-#line 220 "./langdefparser.yy"
+#line 220 "../../../lib/srchilite/langdefparser.yy"
     {
         (yyval.keys) = (yyvsp[(1) - (3)].keys);
         (yyval.keys)->push_back(*(yyvsp[(3) - (3)].string));
@@ -1746,7 +1746,7 @@ yyreduce:
     break;
 
   case 16:
-#line 225 "./langdefparser.yy"
+#line 225 "../../../lib/srchilite/langdefparser.yy"
     {
     	(yyval.keys) = new ElementNamesList;
     	(yyval.keys)->push_back(*(yyvsp[(1) - (1)].string));
@@ -1754,130 +1754,130 @@ yyreduce:
     break;
 
   case 17:
-#line 231 "./langdefparser.yy"
+#line 231 "../../../lib/srchilite/langdefparser.yy"
     { (yyval.stringdef) = (yyvsp[(2) - (2)].stringdef); }
     break;
 
   case 18:
-#line 232 "./langdefparser.yy"
+#line 232 "../../../lib/srchilite/langdefparser.yy"
     { (yyval.stringdef) = 0; }
     break;
 
   case 19:
-#line 235 "./langdefparser.yy"
+#line 235 "../../../lib/srchilite/langdefparser.yy"
     { (yyval.tok) = -1; }
     break;
 
   case 20:
-#line 236 "./langdefparser.yy"
+#line 236 "../../../lib/srchilite/langdefparser.yy"
     { (yyval.tok) = (yyvsp[(2) - (2)].level); }
     break;
 
   case 21:
-#line 237 "./langdefparser.yy"
+#line 237 "../../../lib/srchilite/langdefparser.yy"
     { (yyval.tok) = 0; }
     break;
 
   case 22:
-#line 240 "./langdefparser.yy"
+#line 240 "../../../lib/srchilite/langdefparser.yy"
     { (yyval.level) = (yyvsp[(1) - (1)].level); }
     break;
 
   case 23:
-#line 241 "./langdefparser.yy"
+#line 241 "../../../lib/srchilite/langdefparser.yy"
     { (yyval.level) = 1; }
     break;
 
   case 24:
-#line 244 "./langdefparser.yy"
+#line 244 "../../../lib/srchilite/langdefparser.yy"
     { (yyval.booloption) = true; }
     break;
 
   case 25:
-#line 245 "./langdefparser.yy"
+#line 245 "../../../lib/srchilite/langdefparser.yy"
     { (yyval.booloption) = false; }
     break;
 
   case 26:
-#line 248 "./langdefparser.yy"
+#line 248 "../../../lib/srchilite/langdefparser.yy"
     { (yyval.booloption) = true; }
     break;
 
   case 27:
-#line 249 "./langdefparser.yy"
+#line 249 "../../../lib/srchilite/langdefparser.yy"
     { (yyval.booloption) = false; }
     break;
 
   case 28:
-#line 252 "./langdefparser.yy"
+#line 252 "../../../lib/srchilite/langdefparser.yy"
     { (yyval.tok) = 1; }
     break;
 
   case 29:
-#line 253 "./langdefparser.yy"
+#line 253 "../../../lib/srchilite/langdefparser.yy"
     { (yyval.tok) = 2; }
     break;
 
   case 30:
-#line 254 "./langdefparser.yy"
+#line 254 "../../../lib/srchilite/langdefparser.yy"
     { (yyval.tok) = 0; }
     break;
 
   case 31:
-#line 257 "./langdefparser.yy"
+#line 257 "../../../lib/srchilite/langdefparser.yy"
     { (yyval.booloption) = true; }
     break;
 
   case 32:
-#line 258 "./langdefparser.yy"
+#line 258 "../../../lib/srchilite/langdefparser.yy"
     { (yyval.booloption) = false; }
     break;
 
   case 33:
-#line 261 "./langdefparser.yy"
+#line 261 "../../../lib/srchilite/langdefparser.yy"
     { (yyval.booloption) = true; }
     break;
 
   case 34:
-#line 262 "./langdefparser.yy"
+#line 262 "../../../lib/srchilite/langdefparser.yy"
     { (yyval.booloption) = false; }
     break;
 
   case 35:
-#line 265 "./langdefparser.yy"
+#line 265 "../../../lib/srchilite/langdefparser.yy"
     { (yyval.stringdefs) = (yyvsp[(1) - (3)].stringdefs); (yyval.stringdefs)->push_back((yyvsp[(3) - (3)].stringdef)); }
     break;
 
   case 36:
-#line 266 "./langdefparser.yy"
+#line 266 "../../../lib/srchilite/langdefparser.yy"
     {
                 (yyval.stringdefs) = new StringDefs;
                 (yyval.stringdefs)->push_back((yyvsp[(1) - (1)].stringdef)); }
     break;
 
   case 37:
-#line 271 "./langdefparser.yy"
+#line 271 "../../../lib/srchilite/langdefparser.yy"
     {
               (yyval.stringdef) = (yyvsp[(1) - (1)].stringdef);
             }
     break;
 
   case 38:
-#line 274 "./langdefparser.yy"
+#line 274 "../../../lib/srchilite/langdefparser.yy"
     {
               (yyval.stringdef) = new StringDef(*(yyvsp[(1) - (1)].string), true);
             }
     break;
 
   case 39:
-#line 277 "./langdefparser.yy"
+#line 277 "../../../lib/srchilite/langdefparser.yy"
     {
               (yyval.stringdef) = new StringDef(*(yyvsp[(1) - (1)].string));
             }
     break;
 
   case 40:
-#line 280 "./langdefparser.yy"
+#line 280 "../../../lib/srchilite/langdefparser.yy"
     {
               if (! vardefinitions->contains(*(yyvsp[(1) - (1)].string))) {
                 yyerror("undefined variable " + *(yyvsp[(1) - (1)].string));
@@ -1888,7 +1888,7 @@ yyreduce:
     break;
 
   case 41:
-#line 287 "./langdefparser.yy"
+#line 287 "../../../lib/srchilite/langdefparser.yy"
     {
               (yyval.stringdef) = new StringDef(*(yyvsp[(1) - (1)].string));
               (yyval.stringdef)->setBackRef(true);
@@ -1896,7 +1896,7 @@ yyreduce:
     break;
 
   case 42:
-#line 291 "./langdefparser.yy"
+#line 291 "../../../lib/srchilite/langdefparser.yy"
     {
               (yyval.stringdef) = StringDef::concat((yyvsp[(1) - (3)].stringdef), (yyvsp[(3) - (3)].stringdef));
               delete (yyvsp[(1) - (3)].stringdef);
@@ -1905,7 +1905,7 @@ yyreduce:
     break;
 
   case 43:
-#line 296 "./langdefparser.yy"
+#line 296 "../../../lib/srchilite/langdefparser.yy"
     {
             // this token is used by the scanner to signal an error
             // in scanning a string with backreference
@@ -1917,28 +1917,28 @@ yyreduce:
     break;
 
   case 44:
-#line 306 "./langdefparser.yy"
+#line 306 "../../../lib/srchilite/langdefparser.yy"
     {
               (yyval.stringdef) = (yyvsp[(1) - (1)].stringdef);
             }
     break;
 
   case 45:
-#line 309 "./langdefparser.yy"
+#line 309 "../../../lib/srchilite/langdefparser.yy"
     {
               (yyval.stringdef) = new StringDef(*(yyvsp[(1) - (1)].string), true);
             }
     break;
 
   case 46:
-#line 312 "./langdefparser.yy"
+#line 312 "../../../lib/srchilite/langdefparser.yy"
     {
               (yyval.stringdef) = new StringDef(*(yyvsp[(1) - (1)].string));
             }
     break;
 
   case 47:
-#line 315 "./langdefparser.yy"
+#line 315 "../../../lib/srchilite/langdefparser.yy"
     {
               if (! vardefinitions->contains(*(yyvsp[(1) - (1)].string))) {
                 yyerror("undefined variable " + *(yyvsp[(1) - (1)].string));
@@ -1949,7 +1949,7 @@ yyreduce:
     break;
 
   case 48:
-#line 322 "./langdefparser.yy"
+#line 322 "../../../lib/srchilite/langdefparser.yy"
     {
               (yyval.stringdef) = StringDef::concat((yyvsp[(1) - (3)].stringdef), (yyvsp[(3) - (3)].stringdef));
               delete (yyvsp[(1) - (3)].stringdef);
@@ -1958,7 +1958,7 @@ yyreduce:
     break;
 
   case 49:
-#line 327 "./langdefparser.yy"
+#line 327 "../../../lib/srchilite/langdefparser.yy"
     {
             // this token is used by the scanner to signal an error
             // in scanning a string with backreference
@@ -2191,7 +2191,7 @@ yyreturn:
 }
 
 
-#line 337 "./langdefparser.yy"
+#line 337 "../../../lib/srchilite/langdefparser.yy"
 
 
 extern int langdef_lex_destroy (void);
