@@ -96,7 +96,7 @@
 
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
 typedef union YYSTYPE
-#line 91 "./langdefparser.yy"
+#line 91 "../../../lib/srchilite/langdefparser.yy"
 {
   int tok ; /* command */
   bool booloption ;
