@@ -140,7 +140,7 @@
 
 
 /* Copy the first part of user declarations.  */
-#line 1 "./outlangdefparser.yy"
+#line 1 "../../../lib/srchilite/outlangdefparser.yy"
 
 /*
  * Copyright (C) 1999-2007 Lorenzo Bettini <http://www.lorenzobettini.it>
@@ -218,7 +218,7 @@ static bool includedFileNotFound = false;
 
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
 typedef union YYSTYPE
-#line 58 "./outlangdefparser.yy"
+#line 58 "../../../lib/srchilite/outlangdefparser.yy"
 {
   int tok ; /* command */
   bool booloption ;
@@ -1485,7 +1485,7 @@ yyreduce:
   switch (yyn)
     {
         case 5:
-#line 82 "./outlangdefparser.yy"
+#line 82 "../../../lib/srchilite/outlangdefparser.yy"
     {
     textstyles->docTemplate = DocTemplate(*(yyvsp[(2) - (4)].string), *(yyvsp[(3) - (4)].string));
     delete (yyvsp[(2) - (4)].string);
@@ -1494,7 +1494,7 @@ yyreduce:
     break;
 
   case 6:
-#line 89 "./outlangdefparser.yy"
+#line 89 "../../../lib/srchilite/outlangdefparser.yy"
     {
     textstyles->noDocTemplate = DocTemplate(*(yyvsp[(2) - (4)].string), *(yyvsp[(3) - (4)].string));
     delete (yyvsp[(2) - (4)].string);
@@ -1503,7 +1503,7 @@ yyreduce:
     break;
 
   case 7:
-#line 96 "./outlangdefparser.yy"
+#line 96 "../../../lib/srchilite/outlangdefparser.yy"
     {
     textstyles->starting_template = *(yyvsp[(2) - (2)].string);
     delete (yyvsp[(2) - (2)].string);
@@ -1511,7 +1511,7 @@ yyreduce:
     break;
 
   case 8:
-#line 102 "./outlangdefparser.yy"
+#line 102 "../../../lib/srchilite/outlangdefparser.yy"
     {
     textstyles->style_separator = *(yyvsp[(2) - (2)].string);
     delete (yyvsp[(2) - (2)].string);
@@ -1519,7 +1519,7 @@ yyreduce:
     break;
 
   case 9:
-#line 108 "./outlangdefparser.yy"
+#line 108 "../../../lib/srchilite/outlangdefparser.yy"
     {
   textstyles->bold = *(yyvsp[(2) - (2)].string);
   delete (yyvsp[(2) - (2)].string);
@@ -1527,7 +1527,7 @@ yyreduce:
     break;
 
   case 10:
-#line 114 "./outlangdefparser.yy"
+#line 114 "../../../lib/srchilite/outlangdefparser.yy"
     {
   textstyles->italics = *(yyvsp[(2) - (2)].string);
   delete (yyvsp[(2) - (2)].string);
@@ -1535,7 +1535,7 @@ yyreduce:
     break;
 
   case 11:
-#line 120 "./outlangdefparser.yy"
+#line 120 "../../../lib/srchilite/outlangdefparser.yy"
     {
   textstyles->underline = *(yyvsp[(2) - (2)].string);
   delete (yyvsp[(2) - (2)].string);
@@ -1543,7 +1543,7 @@ yyreduce:
     break;
 
   case 12:
-#line 126 "./outlangdefparser.yy"
+#line 126 "../../../lib/srchilite/outlangdefparser.yy"
     {
   textstyles->fixed = *(yyvsp[(2) - (2)].string);
   delete (yyvsp[(2) - (2)].string);
@@ -1551,7 +1551,7 @@ yyreduce:
     break;
 
   case 13:
-#line 132 "./outlangdefparser.yy"
+#line 132 "../../../lib/srchilite/outlangdefparser.yy"
     {
   textstyles->notfixed = *(yyvsp[(2) - (2)].string);
   delete (yyvsp[(2) - (2)].string);
@@ -1559,7 +1559,7 @@ yyreduce:
     break;
 
   case 14:
-#line 138 "./outlangdefparser.yy"
+#line 138 "../../../lib/srchilite/outlangdefparser.yy"
     {
   textstyles->color = *(yyvsp[(2) - (2)].string);
   delete (yyvsp[(2) - (2)].string);
@@ -1567,7 +1567,7 @@ yyreduce:
     break;
 
   case 15:
-#line 144 "./outlangdefparser.yy"
+#line 144 "../../../lib/srchilite/outlangdefparser.yy"
     {
   textstyles->bg_color = *(yyvsp[(2) - (2)].string);
   delete (yyvsp[(2) - (2)].string);
@@ -1575,7 +1575,7 @@ yyreduce:
     break;
 
   case 16:
-#line 150 "./outlangdefparser.yy"
+#line 150 "../../../lib/srchilite/outlangdefparser.yy"
     {
   textstyles->onestyle = *(yyvsp[(2) - (2)].string);
   delete (yyvsp[(2) - (2)].string);
@@ -1583,7 +1583,7 @@ yyreduce:
     break;
 
   case 17:
-#line 156 "./outlangdefparser.yy"
+#line 156 "../../../lib/srchilite/outlangdefparser.yy"
     {
   textstyles->file_extension = *(yyvsp[(2) - (2)].string);
   delete (yyvsp[(2) - (2)].string);
@@ -1591,7 +1591,7 @@ yyreduce:
     break;
 
   case 18:
-#line 162 "./outlangdefparser.yy"
+#line 162 "../../../lib/srchilite/outlangdefparser.yy"
     {
   textstyles->refstyle.anchor = TextStyle(*(yyvsp[(2) - (2)].string), anchor_vars);
   delete (yyvsp[(2) - (2)].string);
@@ -1599,7 +1599,7 @@ yyreduce:
     break;
 
   case 19:
-#line 168 "./outlangdefparser.yy"
+#line 168 "../../../lib/srchilite/outlangdefparser.yy"
     {
   textstyles->line_prefix = *(yyvsp[(2) - (2)].string);
   delete (yyvsp[(2) - (2)].string);
@@ -1607,7 +1607,7 @@ yyreduce:
     break;
 
   case 20:
-#line 174 "./outlangdefparser.yy"
+#line 174 "../../../lib/srchilite/outlangdefparser.yy"
     {
   textstyles->linenum = *(yyvsp[(2) - (2)].string);
   delete (yyvsp[(2) - (2)].string);
@@ -1615,7 +1615,7 @@ yyreduce:
     break;
 
   case 21:
-#line 180 "./outlangdefparser.yy"
+#line 180 "../../../lib/srchilite/outlangdefparser.yy"
     {
   if (textstyles->refstyle.inline_reference.empty())
     textstyles->refstyle.inline_reference = TextStyle(*(yyvsp[(2) - (2)].string), reference_vars);
@@ -1628,7 +1628,7 @@ yyreduce:
     break;
 
   case 22:
-#line 191 "./outlangdefparser.yy"
+#line 191 "../../../lib/srchilite/outlangdefparser.yy"
     {
   textstyles->refstyle.inline_reference = TextStyle(*(yyvsp[(2) - (2)].string), reference_vars);
   delete (yyvsp[(2) - (2)].string);
@@ -1636,7 +1636,7 @@ yyreduce:
     break;
 
   case 23:
-#line 197 "./outlangdefparser.yy"
+#line 197 "../../../lib/srchilite/outlangdefparser.yy"
     {
   textstyles->refstyle.postline_reference = TextStyle(*(yyvsp[(2) - (2)].string), reference_vars);
   delete (yyvsp[(2) - (2)].string);
@@ -1644,7 +1644,7 @@ yyreduce:
     break;
 
   case 24:
-#line 203 "./outlangdefparser.yy"
+#line 203 "../../../lib/srchilite/outlangdefparser.yy"
     {
   textstyles->refstyle.postdoc_reference = TextStyle(*(yyvsp[(2) - (2)].string), reference_vars);
   delete (yyvsp[(2) - (2)].string);
@@ -1652,21 +1652,21 @@ yyreduce:
     break;
 
   case 25:
-#line 209 "./outlangdefparser.yy"
+#line 209 "../../../lib/srchilite/outlangdefparser.yy"
     {
   textstyles->colorMap = colorMap;
 }
     break;
 
   case 26:
-#line 214 "./outlangdefparser.yy"
+#line 214 "../../../lib/srchilite/outlangdefparser.yy"
     {
   textstyles->charTranslator = charTranslator;
 }
     break;
 
   case 27:
-#line 217 "./outlangdefparser.yy"
+#line 217 "../../../lib/srchilite/outlangdefparser.yy"
     {
             // this token is used by the scanner to signal an error
             // in opening an include file
@@ -1678,7 +1678,7 @@ yyreduce:
     break;
 
   case 31:
-#line 236 "./outlangdefparser.yy"
+#line 236 "../../../lib/srchilite/outlangdefparser.yy"
     {
   (*colorMap)[*(yyvsp[(1) - (2)].string)] = *(yyvsp[(2) - (2)].string);
   delete (yyvsp[(1) - (2)].string);
@@ -1687,7 +1687,7 @@ yyreduce:
     break;
 
   case 32:
-#line 243 "./outlangdefparser.yy"
+#line 243 "../../../lib/srchilite/outlangdefparser.yy"
     {
   colorMap->setDefault(*(yyvsp[(2) - (2)].string));
   delete (yyvsp[(2) - (2)].string);
@@ -1695,7 +1695,7 @@ yyreduce:
     break;
 
   case 36:
-#line 258 "./outlangdefparser.yy"
+#line 258 "../../../lib/srchilite/outlangdefparser.yy"
     {
   charTranslator->set_translation(*(yyvsp[(1) - (2)].string), *(yyvsp[(2) - (2)].string));
   delete (yyvsp[(1) - (2)].string);
@@ -1919,7 +1919,7 @@ yyreturn:
 }
 
 
-#line 264 "./outlangdefparser.yy"
+#line 264 "../../../lib/srchilite/outlangdefparser.yy"
 
 
 extern int outlangdef_lex_destroy (void);
