@@ -106,7 +106,7 @@
 
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
 typedef union YYSTYPE
-#line 58 "./outlangdefparser.yy"
+#line 58 "../../../lib/srchilite/outlangdefparser.yy"
 {
   int tok ; /* command */
   bool booloption ;
