@@ -70,7 +70,7 @@
 
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
 typedef union YYSTYPE
-#line 70 "./stylecssparser.yy"
+#line 70 "../../../lib/srchilite/stylecssparser.yy"
 {
   int tok ; /* command */
   const std::string * string ; /* string : id, ... */
